// 完毕：
using System;
using System.IO;
using System.Drawing;
using GrapeCity.Documents.Pdf;
using GrapeCity.Documents.Text;
using GrapeCity.Documents.Pdf.Structure;
using GrapeCity.Documents.Pdf.MarkedContent;

namespace DsPdfWeb.Demos.Basics
{
    // 此示例演示如何创建标记（结构化）PDF。
    // 要查看/探索标签，请在 Adob​​e Acrobat Pro 中打开文档并转到
    // 查看 |导航面板|标签。
    public class TagParagraphs
    {
        public int CreatePDF(Stream stream)
        {
            var doc = new GcPdfDocument();
            var rnd = Common.Util.NewRandom();
            int pageCount = rnd.Next(3, 7);

            // 创建 Part 元素，它将包含 P（段落）元素
            var sePart = new StructElement("Part");
            doc.StructTreeRoot.Children.Add(sePart);

            // 添加一些页面，在每个页面上添加一些段落并标记它们：
            for (int pageIndex = 0; pageIndex < pageCount; ++pageIndex)
            {
                // 添加页面：
                var page = doc.Pages.Add();
                var g = page.Graphics;
                const float margin = 36;
                const float dy = 18;

                // 添加一些段落：
                int paraCount = rnd.Next(1, 5);
                float y = margin;
                for (int i = 0; i < paraCount; ++i)
                {
                    // 创建段落元素：
                    var seParagraph = new StructElement("P") { DefaultPage = page };
                    // 将其添加到 Part 元素：
                    sePart.Children.Add(seParagraph);

                    // 创建段落：
                    var tl = g.CreateTextLayout();
                    tl.DefaultFormat.Font = StandardFonts.Helvetica;
                    tl.DefaultFormat.FontSize = 12;
                    tl.Append(Common.Util.LoremIpsum(1, 1, 5, 5, 10));
                    tl.MaxWidth = page.Size.Width;
                    tl.MarginLeft = tl.MarginRight = margin;
                    tl.PerformLayout(true);

                    // 在标记内容中绘制 TextLayout：
                    g.BeginMarkedContent(new TagMcid("P", i));
                    g.DrawTextLayout(tl, new PointF(0, y));
                    g.EndMarkedContent();

                    y += tl.ContentHeight + dy;

                    // 将内容项添加到段落 StructElement：
                    seParagraph.ContentItems.Add(new McidContentItemLink(i));
                }
            }

            // 将文档标记为已标记：
            doc.MarkInfo.Marked = true;

            // 完毕：
            doc.Save(stream);
            return doc.Pages.Count;
        }
    }
}
